Struct quilkin::Config [−][src]
#[non_exhaustive]pub struct Config { pub version: Version, pub proxy: Proxy, pub admin: Admin, pub source: Source, }
Config is the configuration of a proxy
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.version: Versionproxy: Proxyadmin: Adminsource: SourceImplementations
Attempts to locate and parse a Config located at either path, the
$QUILKIN_CONFIG environment variable if set, the current directory,
or the /etc/quilkin directory (on unix platforms only). Returns an
error if the found configuration is invalid, or if no configuration
could be found at any location.
Attempts to deserialize input as a YAML object representing Self.